@@ -129,9 +129,9 @@ module SiSU_DbImport
       select_first_match=%{
         SELECT metadata_and_text.tid
         FROM metadata_and_text
-        WHERE metadata_and_text.src_filename = '#{@opt.fns}'
+        WHERE metadata_and_text.src_filename = '#{@md.fns}'
         AND metadata_and_text.language_document_char = '#{@opt.lng}'
-      ;}
+      ;} # note, for .ssm: @md.fns (is set during runtime & is) != @opt.fns @md.opt.fns
       file_exist=@sql_type=~/sqlite/ \
       ? @conn.get_first_value(select_first_match)
       : @conn.select_one(select_first_match)
