@@ -70,8 +70,6 @@ module SiSU
     include SiSU_Param
   require_relative 'defaults'                          # defaults.rb
     include SiSU_Viz
-  require_relative 'help'                              # help.rb
-    include SiSU_Help
   require_relative 'utils'                             # utils.rb
   require 'uri'
   class HubMaster
@@ -208,8 +206,8 @@ module SiSU
       require_relative 'remote'                        # remote.rb
       SiSU_Remote::Put.new(@opt).scp_base_all
     end
-    def cgi                                            # -F
-      require_relative 'cgi'                           # cgi.rb
+    def cgi                                                # -F
+      require_relative 'cgi'                               # cgi.rb
       SiSU_CGI::SearchSQL.new(@opt).read
     end
     def termsheet                                          # -t
@@ -372,10 +370,10 @@ module SiSU
     end
     def do_loop_files_on_given_option_pre
       begin
-        if @opt.act[:zap][:set]==:on                     #% --zap, -Z
+        if @opt.act[:zap][:set]==:on                   #% --zap, -Z
           OptionLoopFiles.new(@opt).loop_files_on_given_option do
             require_relative 'zap'
-            SiSU_Zap::Source.new(@opt).read              # -Z     zap.rb
+            SiSU_Zap::Source.new(@opt).read            # -Z     zap.rb
           end
         end
       ensure
@@ -423,8 +421,8 @@ module SiSU
           end
           if (@opt.act[:sisupod][:set]==:on \
           || @opt.act[:share_source][:set]==:on) \
-          and @opt.act[:manifest][:set]==:on              #% --manifest, -y
-            require_relative 'manifest'                  # -y     manifest.rb
+          and @opt.act[:manifest][:set]==:on           #% --manifest, -y
+            require_relative 'manifest'                # -y     manifest.rb
             begin
             ensure
               OptionLoopFiles.new(@opt).loop_files_on_given_option_bundle do
@@ -455,7 +453,6 @@ module SiSU
         end
       end
       if @opt.cmd =~/T/                                #% -T termsheet/standard form
-        SiSU_Help::Help.new('termsheet').help_request
         @opt.files.each do |fns|
           if FileTest.file?(fns)
             @opt.fns=fns
@@ -519,10 +516,7 @@ module SiSU
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
       flag=SiSU_Env::InfoProcessingFlag.new
       if @opt.act[:version_info][:set]==:on              #% version information
-        SiSU_Help::Help.new('env',@opt).sisu_version
-      end
-      if @opt.act[:license][:set]==:on                   #% license information
-        SiSU_Help::Help.new('license',@opt).help_request
+        SiSU_Env::InfoAbout.new(@opt).sisu_version
       end
       if @opt.act[:dal][:set]==:on \
       or @opt.act[:maintenance][:set]==:on               #% --maintenance, -m for -C
@@ -698,7 +692,7 @@ module SiSU
           end
         elsif action_on_file_ == :true \
         and @opt.files.length == 0
-          STDERR.puts %{requested action requires valid sisu markup file filename (.sst .ssm) or wildcard (that includes a valid filame)}
+          STDERR.puts %{requested action requires valid sisu markup file [filename (.sst .ssm)] or wildcard (that includes a valid filename)}
           puts SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).set(:fuchsia) if @opt.cmd =~/[MV]/
         end
       elsif @opt.mod.inspect =~/--query/
@@ -707,13 +701,6 @@ module SiSU
       elsif @opt.mod.inspect =~/--identify/
         require_relative 'sst_identify_markup'          # sst_identify_markup.rb
         markup_version=SiSU_Markup::MarkupIdentify.new(@opt).markup_version?
-      elsif  @opt.mod.inspect =~/--about/              #% help instructions
-        if @opt.mod.inspect =~/--about/ \
-        and not @opt.what.empty?
-          SiSU_Help::Help.new(@opt.what,'color_off').help_request
-        else
-          SiSU_Help::Help.new('list','color_off').help_request
-        end
       elsif  @opt.mod.inspect =~/--sitemaps/           #% sitemaps
         require_relative 'sitemaps'                    # sitemaps.rb
         SiSU_Sitemaps::Source.new(@opt).read
@@ -721,19 +708,9 @@ module SiSU
           require_relative 'remote'                    # remote.rb
           SiSU_Remote::Put.new(@opt).rsync_sitemaps
         end
-      else                                                 #% help instructions
-        unless @opt.mod.inspect =~/--convert|--to|--from|--harvest/
-          if @opt.mod.inspect =~/--help/ \
-          and not @opt.what.empty?
-            SiSU_Help::Help.new(@opt.what).help_request
-          elsif @opt.mod.inspect =~/--help/
-            SiSU_Help::Help.new('list').help_request
-          else
-            SiSU_Help::Help.new('env',@opt).sisu_version
-            tell=SiSU_Screen::Ansi.new('',"  for HELP type:\n\tsisu --help [help request]\n\tman sisu\n  or see the system or online documentation on SiSU:\n    #{Config::CONFIG['datadir']}/doc/sisu/\n    <http://www.jus.uio.no/sisu/>\n    <http://sisudoc.org/>")
-            tell.puts_grey
-          end
-        end
+      else                                             #% sisu help refer to man pages
+        SiSU_Env::InfoAbout.new(@opt).sisu_version
+        SiSU_Env::InfoAbout.new(@opt).sisu_about
       end
       @opt.files.each do |fns|
         if FileTest.file?(fns)
