@@ -165,7 +165,19 @@ module SiSU_CGI_SQL
     </head>
     <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
     <table summary="band" border="0" cellpadding="3" cellspacing="0">
-    <tr><td align="left" bgcolor="#ffffff"><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{@image_src}/sisu.png" alt="SiSU --&gt;" /></a></td><td>
+    <tr><td width="20%">
+     <table summary="home button / home information" border="0" cellpadding="3" cellspacing="0">
+     <tr><td align="left" bgcolor="#ffffff">
+      <br /><a href="http://sisudoc.org/" target="_top">
+        <b>SiSU</b>
+      </a>
+      <br /><a href="http://git.sisudoc.org/" target="_top">
+        git
+      </a>
+     </td></tr>
+     </table>
+    </td>
+    <td>
       <label for="find"><b>#{@env.sample_search_form_title(@opt.dir_structure_by)}</b></label>
     </td></tr>
     </table>
@@ -541,26 +553,29 @@ module SiSU_CGI_SQL
 <table summary="SiSU summary" bgcolor="#ffffff" cellpadding="2" border="0">
   <!-- widget sisu -->
 <tr><td valign="top" width="10%">
-  <p class="tiny_left"><font color="#666666" size="2">
-    <a href="http://www.jus.uio.no/sisu" >
-      <img border="0" src="#{@image_src}/sisu.png" alt="SiSU" width="120" height="39" />
-    </a>
-  </font></p>
-</td><td valign="top" width="45%">
+ <table summary="home button / home information" border="0" cellpadding="3" cellspacing="0">
+ <tr><td align="left" bgcolor="#ffffff">
+  <br /><a href="http://sisudoc.org/" target="_top">
+    <b>SiSU</b>
+  </a>
+  <br /><a href="http://git.sisudoc.org/" target="_top">
+    git
+  </a>
+ </td></tr>
+ </table>
+</td>
+<td valign="top" width="45%">
 <!-- SiSU Rights -->
   <p class="tiny_left"><font color="#666666" size="2">
     Generated by
-    <a href="http://www.jus.uio.no/sisu" >
-      #{v[:project]}</a> #{v[:version]} #{v[:date]} (#{v[:date_stamp]})
+      #{v[:project]} #{v[:version]} #{v[:date]} (#{v[:date_stamp]})
     <br />
-    <a href="http://www.jus.uio.no/sisu" >
+    <a href="http://www.sisudoc.org" >
     <b>#{v[:project]}</b></a> <sup>&copy;</sup> Ralph Amissah
     1993, current 2013.
     All Rights Reserved.
     <br />
-    <a href="http://www.jus.uio.no/sisu" >
-      #{v[:project]}</a>
-    is software for document structuring, publishing and search,
+      #{v[:project]} is software for document structuring, publishing and search,
     <br />
     <a href="http://www.jus.uio.no/sisu" >
       www.jus.uio.no/sisu
@@ -569,6 +584,10 @@ module SiSU_CGI_SQL
     <a href="http://www.sisudoc.org" >
       www.sisudoc.org
     </a>
+    sources
+    <a href="http://git.sisudoc.org" >
+      git.sisudoc.org
+    </a>
   <br />
     <i>w3 since October 3 1993</i>
     <a href="mailto:ralph@amissah.com" >
@@ -589,7 +608,7 @@ module SiSU_CGI_SQL
     #{v[:project]} using:
     <br />Standard SiSU markup syntax,
     <br />Standard SiSU meta-markup syntax, and the
-    <br />Standard SiSU <u>object citation numbering</u> and system, (object/text positioning system)
+    <br />Standard SiSU <u>object citation numbering</u> and system, (object/text identifying/locating system)
   <br />
     <sup>&copy;</sup> Ralph Amissah 1997, current 2013.
     All Rights Reserved.
@@ -599,7 +618,7 @@ module SiSU_CGI_SQL
 <tr><td valign="top" width="10%">
   <p class="tiny_left"><font color="#666666" size="2">
     <a href="http://www.gnu.org/licenses/gpl.html">
-      <img border="0" src="#{@image_src}/gplv3_free_software.png" alt="GPLv3" width="127" height="51" />
+      .:
     </a>
   </font></p>
 </td><td valign="top" width="45%">
@@ -898,7 +917,7 @@ module SiSU_CGI_SQL
                     #% text_objects_body
           s_contents.each do |c|                                               #% text body
             location=c['src_filename'][/(.+?)\.(?:ssm\.sst|sst)$/,1]
-            file_suffix=c['src_filename'][/.+?\.(_?sst|ssm)$/,1]
+            file_suffix=c['src_filename'][/.+?\.(ssm\.sst|sst)$/,1]
             lang=if location =~ /\S+?~(\S\S\S?)$/
               l=location[/\S+?~(\S\S\S?)$/,1]
               location=location.gsub(/(\S+?)~\S\S\S?/,'\1')
@@ -990,7 +1009,7 @@ module SiSU_CGI_SQL
           oldtid = 0
           s_endnotes.each do |e|                                               #% endnotes
             location=e['src_filename'][/(.+?)\.(?:ssm\.sst|sst)$/,1]
-            file_suffix=e['src_filename'][/.+?\.(_?sst|ssm)$/,1]
+            file_suffix=e['src_filename'][/.+?\.(ssm\.sst|sst)$/,1]
             lang=if location =~ /\S+?~(\S\S\S?)$/
               l=location[/\S+?~(\S\S\S?)$/,1]
               location=location.gsub(/(\S+?)~\S\S\S?/,'\1')
