@@ -60,7 +60,6 @@
 
 =end
 module  SiSU_DBI                                                                 #% database building
-  require_relative 'help'                               # help.rb
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env; include SiSU_Screen
   require_relative 'param'                              # param.rb
@@ -108,7 +107,11 @@ module  SiSU_DBI
         @conn=@db.psql.conn_dbi
       rescue
         if @opt.mod.inspect=~/--(createall|create)/
-          puts %{manually create the database: "#{@db.db}" if it does not yet exist}
+          cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
+          puts <<-WOK
+manually create the database: "#{cX.green}#{@db.db}#{cX.off}" if it does not yet exist
+  #{cX.yellow}createdb #{@db.db}#{cX.off}
+          WOK
           #sudo su -p postgres;  createdb #{@db.db}; #[createuser?]
         end
       ensure
